tlslite.errors.TLSAbruptCloseError

Package tlslite :: Module errors :: Class TLSAbruptCloseError |
[show private | hide private]
[frames | no frames]

## Class TLSAbruptCloseError

    Exception --+
                |
         TLSError --+
                    |
                   TLSAbruptCloseError

The socket was closed without a proper TLS shutdown.

The TLS specification mandates that an alert of some sort must be sent before the underlying socket is closed. If the socket is closed without this, it could signify that an attacker is trying to truncate the connection. It could also signify a misbehaving TLS implementation, or a random network failure.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net